/****************************************************************************
 * @file     func_in_SRAM.c
 * @version  V1.00
 * @brief    Example to load function to SRAM and call it.
 * @note
 * Copyright (C) 2016 Nuvoton Technology Corp. All rights reserved.
 ****************************************************************************/

#include "M451Series.h"
#include "func_in_SRAM.h"

/*** ATTENTION **************************************************************

  All functions and global variables in func_in_SRAM.c file are put at
  the RAM area which is assigned in scatter file (LoadFuncToRAM.sct).

  All functions here only can access global variables in the C file,
  DON'T access global variables in other C files.

  All functions here only can call functions in the C file,
  DON'T call functions in other C files.

  All functions in the C file also use the main stack.
  It doesn't create and use its own stack.

 ****************************************************************************/

/****************************************************************************
  It is fine to use 'static' or not to declare global variables or functions.

static uint8_t gu8Table[100];
const int32_t gTable[] = {100, 200, 300, 400, 500 , 600};
 ****************************************************************************/

/* static */ int32_t RAM_func(int32_t x, int32_t y)
{

    /* This is a simple example to return the bigger value */

    if(x >= y)
        return x;
    else
        return y;
}

/****************************************************************************
  The function uses as the entry point for main code to invoke the function in RAM.
  It always locates at the beginning of the specified RAM area. DON'T change
  __attribute__ declaration.
  To change the address of the RAM area, modify scatter file (LoadFuncToSRAM.sct).

  FuncEntry() prototype (return value and parameters) can be modified to match
  the real main function in the RAM area. Please also modify the prototype
  declaration PFUNC in func_in_RAM.h.
 ****************************************************************************/

__attribute__((section("RAM_FUNC_ENTRY"))) int32_t FuncEntry(int32_t x, int32_t y)
{
    /* Call the real main function in the C file */
    return RAM_func(x, y);
}

/*** (C) COPYRIGHT 2016 Nuvoton Technology Corp. ***/
