/****************************************************************************
 * @file     func_in_SRAM.h
 * @version  V1.00
 * @brief    Header for load function to SRAM.
 * @note
 * Copyright (C) 2016 Nuvoton Technology Corp. All rights reserved.
 ****************************************************************************/

#ifndef _FUNC_IN_SRAM_H_
#define _FUNC_IN_SRAM_H_

#include "M451Series.h"

/****************************************************************************
    FLOW TO USE THE SAMPLE CODE
    ---------------------------

 1) Define following BUILD_FUNC to compile the code, then find
    the size of RW_IRAM2 region. You can find similar content
    like follows in map file (LoadFuncToSRAM.map).

    Execution Region RW_IRAM2 (Base: 0x20007000, Size: 0x0000000c, Max: 0x00001000, ABSOLUTE)

 2) Fill the size to the following FUNC_SIZE definition.
 3) Compile and run the code again to dump the function binary code
    in SRAM to UART0. Please have a UART console to receive the data.
 4) Copy the dump result to FuncBin[] array in main.c
 5) Undefine BUILD_FUNC to compile and test the function in SRAM.

 ****************************************************************************/

//#define BUILD_FUNC

/****************************************************************************
  Define function prototype for the main in SRAM area
 ****************************************************************************/
typedef int32_t (*PFUNC)(int32_t, int32_t);

/****************************************************************************
  Define the function entry address and length

  NOTE:

  The function entry address is at the beginning of RW_IRAM2 area.
  To change address, you have to modify both here and scatter file (LoadFuncToSRAM.sct).
  The RAM area always start at word (or even) boundary. In thumb mode,
  always call function in odd address, so don't forget '| 0x01' here.
 ****************************************************************************/
#define FUNC_ADDR (0x20007000 | 0x1)
#define FUNC_SIZE (0x0C)


#endif

/*** (C) COPYRIGHT 2016 Nuvoton Technology Corp. ***/
